Module ql2::response [−][src]
Nested message and enum types in Response.
Enums
| ErrorType | If |
| ResponseNote | ResponseNotes are used to provide information about the query response that may be useful for people writing drivers or ORMs. Currently all the notes we send indicate that a stream has certain special properties. |
| ResponseType |