Enum ql2::response::ResponseNote [−][src]
ResponseNotes are used to provide information about the query response that may be useful for people writing drivers or ORMs. Currently all the notes we send indicate that a stream has certain special properties.
Variants
The stream is a changefeed stream (e.g. r.table('test').changes()).
The stream is a point changefeed stream
(e.g. r.table('test').get(0).changes()).
The stream is an order_by_limit changefeed stream
(e.g. r.table('test').order_by(index: 'id').limit(5).changes()).
The stream is a union of multiple changefeed types that can’t be
collapsed to a single type
(e.g. r.table('test').changes().union(r.table('test').get(0).changes())).
The stream is a changefeed stream and includes notes on what state
the changefeed stream is in (e.g. objects of the form {state: 'initializing'}).
Implementations
impl ResponseNote[src]
pub fn is_valid(value: i32) -> bool[src]
Returns true if value is a variant of ResponseNote.
pub fn from_i32(value: i32) -> Option<ResponseNote>[src]
Converts an i32 to a ResponseNote, or None if value is not a valid variant.