Struct ql2::Datum [−][src]
A Datum is a chunk of data that can be serialized to disk or returned to the user in a Response. Currently we only support JSON types, but we may support other types in the future (e.g., a date type or an integer type).
Fields
type: Option<i32>r_bool: Option<bool>r_num: Option<f64>r_str: Option<String>r_array: Vec<Datum>r_object: Vec<AssocPair>Implementations
impl Datum[src]
pub fn type(&self) -> DatumType[src]
Returns the enum value of type, or the default if the field is unset or set to an invalid enum value.
pub fn set_type(&mut self, value: DatumType)[src]
Sets type to the provided enum value.
pub fn r_bool(&self) -> bool[src]
Returns the value of r_bool, or the default value if r_bool is unset.
pub fn r_num(&self) -> f64[src]
Returns the value of r_num, or the default value if r_num is unset.
pub fn r_str(&self) -> &str[src]
Returns the value of r_str, or the default value if r_str is unset.