Module version_dummy

Module version_dummy 

Nested message and enum types in VersionDummy.

Enums

Protocol
The protocol to use after the handshake, specified in V0_3
Version
non-conforming protobuf libraries This enum contains the magic numbers for your version. See THE HIGH-LEVEL VIEW for what to do with it.