Module version_dummy
ql2
2.1.1
Module version_
dummy
Module Items
Enums
In crate ql2
ql2
Module
version_
dummy
Nested message and enum types in
VersionDummy
.
Enums

Protocol
The protocol to use after the handshake, specified in V0_3
Version
non-conforming protobuf libraries This enum contains the magic numbers for your version. See
THE HIGH-LEVEL VIEW
for what to do with it.